pub enum InterpolatedStringElementRef<'a> {
Interpolation(&'a InterpolatedElement),
Literal(&'a InterpolatedStringLiteralElement),
}Variants
Interpolation(&'a InterpolatedElement)
Literal(&'a InterpolatedStringLiteralElement)
Implementations
Sourceimpl<'a> InterpolatedStringElementRef<'a>
impl<'a> InterpolatedStringElementRef<'a>
Sourcepub const fn is_interpolation(&self) -> bool
pub const fn is_interpolation(&self) -> bool
Returns true if self is of variant Interpolation.
Sourcepub fn as_interpolation(&self) -> Option<&&'a InterpolatedElement>
pub fn as_interpolation(&self) -> Option<&&'a InterpolatedElement>
Returns Some if self is a reference of variant Interpolation, and None otherwise.
Sourcepub fn as_mut_interpolation(&mut self) -> Option<&mut &'a InterpolatedElement>
pub fn as_mut_interpolation(&mut self) -> Option<&mut &'a InterpolatedElement>
Returns Some if self is a mutable reference of variant Interpolation, and None otherwise.
Sourcepub fn expect_interpolation(self) -> &'a InterpolatedElementwhere
Self: Debug,
pub fn expect_interpolation(self) -> &'a InterpolatedElementwhere
Self: Debug,
Unwraps the value, yielding the content of Interpolation.
Panics
Panics if the value is not Interpolation, with a panic message including the content of self.
Sourcepub fn interpolation(self) -> Option<&'a InterpolatedElement>
pub fn interpolation(self) -> Option<&'a InterpolatedElement>
Returns Some if self is of variant Interpolation, and None otherwise.
Sourcepub const fn is_literal(&self) -> bool
pub const fn is_literal(&self) -> bool
Returns true if self is of variant Literal.
Sourcepub fn as_literal(&self) -> Option<&&'a InterpolatedStringLiteralElement>
pub fn as_literal(&self) -> Option<&&'a InterpolatedStringLiteralElement>
Returns Some if self is a reference of variant Literal, and None otherwise.
Sourcepub fn as_mut_literal(
&mut self,
) -> Option<&mut &'a InterpolatedStringLiteralElement>
pub fn as_mut_literal( &mut self, ) -> Option<&mut &'a InterpolatedStringLiteralElement>
Returns Some if self is a mutable reference of variant Literal, and None otherwise.
Sourcepub fn expect_literal(self) -> &'a InterpolatedStringLiteralElementwhere
Self: Debug,
pub fn expect_literal(self) -> &'a InterpolatedStringLiteralElementwhere
Self: Debug,
Sourcepub fn literal(self) -> Option<&'a InterpolatedStringLiteralElement>
pub fn literal(self) -> Option<&'a InterpolatedStringLiteralElement>
Returns Some if self is of variant Literal, and None otherwise.