pub enum PatternRef<'a> {
MatchValue(&'a PatternMatchValue),
MatchSingleton(&'a PatternMatchSingleton),
MatchSequence(&'a PatternMatchSequence),
MatchMapping(&'a PatternMatchMapping),
MatchClass(&'a PatternMatchClass),
MatchStar(&'a PatternMatchStar),
MatchAs(&'a PatternMatchAs),
MatchOr(&'a PatternMatchOr),
}Expand description
See also pattern
Variants
MatchValue(&'a PatternMatchValue)
MatchSingleton(&'a PatternMatchSingleton)
MatchSequence(&'a PatternMatchSequence)
MatchMapping(&'a PatternMatchMapping)
MatchClass(&'a PatternMatchClass)
MatchStar(&'a PatternMatchStar)
MatchAs(&'a PatternMatchAs)
MatchOr(&'a PatternMatchOr)
Implementations
Sourceimpl<'a> PatternRef<'a>
impl<'a> PatternRef<'a>
Sourcepub const fn is_match_value(&self) -> bool
pub const fn is_match_value(&self) -> bool
Returns true if self is of variant MatchValue.
Sourcepub fn as_match_value(&self) -> Option<&&'a PatternMatchValue>
pub fn as_match_value(&self) -> Option<&&'a PatternMatchValue>
Returns Some if self is a reference of variant MatchValue, and None otherwise.
Sourcepub fn as_mut_match_value(&mut self) -> Option<&mut &'a PatternMatchValue>
pub fn as_mut_match_value(&mut self) -> Option<&mut &'a PatternMatchValue>
Returns Some if self is a mutable reference of variant MatchValue, and None otherwise.
Sourcepub fn expect_match_value(self) -> &'a PatternMatchValuewhere
Self: Debug,
pub fn expect_match_value(self) -> &'a PatternMatchValuewhere
Self: Debug,
Unwraps the value, yielding the content of MatchValue.
Panics
Panics if the value is not MatchValue, with a panic message including the content of self.
Sourcepub fn match_value(self) -> Option<&'a PatternMatchValue>
pub fn match_value(self) -> Option<&'a PatternMatchValue>
Returns Some if self is of variant MatchValue, and None otherwise.
Sourcepub const fn is_match_singleton(&self) -> bool
pub const fn is_match_singleton(&self) -> bool
Returns true if self is of variant MatchSingleton.
Sourcepub fn as_match_singleton(&self) -> Option<&&'a PatternMatchSingleton>
pub fn as_match_singleton(&self) -> Option<&&'a PatternMatchSingleton>
Returns Some if self is a reference of variant MatchSingleton, and None otherwise.
Sourcepub fn as_mut_match_singleton(
&mut self,
) -> Option<&mut &'a PatternMatchSingleton>
pub fn as_mut_match_singleton( &mut self, ) -> Option<&mut &'a PatternMatchSingleton>
Returns Some if self is a mutable reference of variant MatchSingleton, and None otherwise.
Sourcepub fn expect_match_singleton(self) -> &'a PatternMatchSingletonwhere
Self: Debug,
pub fn expect_match_singleton(self) -> &'a PatternMatchSingletonwhere
Self: Debug,
Unwraps the value, yielding the content of MatchSingleton.
Panics
Panics if the value is not MatchSingleton, with a panic message including the content of self.
Sourcepub fn match_singleton(self) -> Option<&'a PatternMatchSingleton>
pub fn match_singleton(self) -> Option<&'a PatternMatchSingleton>
Returns Some if self is of variant MatchSingleton, and None otherwise.
Sourcepub const fn is_match_sequence(&self) -> bool
pub const fn is_match_sequence(&self) -> bool
Returns true if self is of variant MatchSequence.
Sourcepub fn as_match_sequence(&self) -> Option<&&'a PatternMatchSequence>
pub fn as_match_sequence(&self) -> Option<&&'a PatternMatchSequence>
Returns Some if self is a reference of variant MatchSequence, and None otherwise.
Sourcepub fn as_mut_match_sequence(&mut self) -> Option<&mut &'a PatternMatchSequence>
pub fn as_mut_match_sequence(&mut self) -> Option<&mut &'a PatternMatchSequence>
Returns Some if self is a mutable reference of variant MatchSequence, and None otherwise.
Sourcepub fn expect_match_sequence(self) -> &'a PatternMatchSequencewhere
Self: Debug,
pub fn expect_match_sequence(self) -> &'a PatternMatchSequencewhere
Self: Debug,
Unwraps the value, yielding the content of MatchSequence.
Panics
Panics if the value is not MatchSequence, with a panic message including the content of self.
Sourcepub fn match_sequence(self) -> Option<&'a PatternMatchSequence>
pub fn match_sequence(self) -> Option<&'a PatternMatchSequence>
Returns Some if self is of variant MatchSequence, and None otherwise.
Sourcepub const fn is_match_mapping(&self) -> bool
pub const fn is_match_mapping(&self) -> bool
Returns true if self is of variant MatchMapping.
Sourcepub fn as_match_mapping(&self) -> Option<&&'a PatternMatchMapping>
pub fn as_match_mapping(&self) -> Option<&&'a PatternMatchMapping>
Returns Some if self is a reference of variant MatchMapping, and None otherwise.
Sourcepub fn as_mut_match_mapping(&mut self) -> Option<&mut &'a PatternMatchMapping>
pub fn as_mut_match_mapping(&mut self) -> Option<&mut &'a PatternMatchMapping>
Returns Some if self is a mutable reference of variant MatchMapping, and None otherwise.
Sourcepub fn expect_match_mapping(self) -> &'a PatternMatchMappingwhere
Self: Debug,
pub fn expect_match_mapping(self) -> &'a PatternMatchMappingwhere
Self: Debug,
Unwraps the value, yielding the content of MatchMapping.
Panics
Panics if the value is not MatchMapping, with a panic message including the content of self.
Sourcepub fn match_mapping(self) -> Option<&'a PatternMatchMapping>
pub fn match_mapping(self) -> Option<&'a PatternMatchMapping>
Returns Some if self is of variant MatchMapping, and None otherwise.
Sourcepub const fn is_match_class(&self) -> bool
pub const fn is_match_class(&self) -> bool
Returns true if self is of variant MatchClass.
Sourcepub fn as_match_class(&self) -> Option<&&'a PatternMatchClass>
pub fn as_match_class(&self) -> Option<&&'a PatternMatchClass>
Returns Some if self is a reference of variant MatchClass, and None otherwise.
Sourcepub fn as_mut_match_class(&mut self) -> Option<&mut &'a PatternMatchClass>
pub fn as_mut_match_class(&mut self) -> Option<&mut &'a PatternMatchClass>
Returns Some if self is a mutable reference of variant MatchClass, and None otherwise.
Sourcepub fn expect_match_class(self) -> &'a PatternMatchClasswhere
Self: Debug,
pub fn expect_match_class(self) -> &'a PatternMatchClasswhere
Self: Debug,
Unwraps the value, yielding the content of MatchClass.
Panics
Panics if the value is not MatchClass, with a panic message including the content of self.
Sourcepub fn match_class(self) -> Option<&'a PatternMatchClass>
pub fn match_class(self) -> Option<&'a PatternMatchClass>
Returns Some if self is of variant MatchClass, and None otherwise.
Sourcepub const fn is_match_star(&self) -> bool
pub const fn is_match_star(&self) -> bool
Returns true if self is of variant MatchStar.
Sourcepub fn as_match_star(&self) -> Option<&&'a PatternMatchStar>
pub fn as_match_star(&self) -> Option<&&'a PatternMatchStar>
Returns Some if self is a reference of variant MatchStar, and None otherwise.
Sourcepub fn as_mut_match_star(&mut self) -> Option<&mut &'a PatternMatchStar>
pub fn as_mut_match_star(&mut self) -> Option<&mut &'a PatternMatchStar>
Returns Some if self is a mutable reference of variant MatchStar, and None otherwise.
Sourcepub fn expect_match_star(self) -> &'a PatternMatchStarwhere
Self: Debug,
pub fn expect_match_star(self) -> &'a PatternMatchStarwhere
Self: Debug,
Sourcepub fn match_star(self) -> Option<&'a PatternMatchStar>
pub fn match_star(self) -> Option<&'a PatternMatchStar>
Returns Some if self is of variant MatchStar, and None otherwise.
Sourcepub const fn is_match_as(&self) -> bool
pub const fn is_match_as(&self) -> bool
Returns true if self is of variant MatchAs.
Sourcepub fn as_match_as(&self) -> Option<&&'a PatternMatchAs>
pub fn as_match_as(&self) -> Option<&&'a PatternMatchAs>
Returns Some if self is a reference of variant MatchAs, and None otherwise.
Sourcepub fn as_mut_match_as(&mut self) -> Option<&mut &'a PatternMatchAs>
pub fn as_mut_match_as(&mut self) -> Option<&mut &'a PatternMatchAs>
Returns Some if self is a mutable reference of variant MatchAs, and None otherwise.
Sourcepub fn expect_match_as(self) -> &'a PatternMatchAswhere
Self: Debug,
pub fn expect_match_as(self) -> &'a PatternMatchAswhere
Self: Debug,
Sourcepub fn match_as(self) -> Option<&'a PatternMatchAs>
pub fn match_as(self) -> Option<&'a PatternMatchAs>
Returns Some if self is of variant MatchAs, and None otherwise.
Sourcepub const fn is_match_or(&self) -> bool
pub const fn is_match_or(&self) -> bool
Returns true if self is of variant MatchOr.
Sourcepub fn as_match_or(&self) -> Option<&&'a PatternMatchOr>
pub fn as_match_or(&self) -> Option<&&'a PatternMatchOr>
Returns Some if self is a reference of variant MatchOr, and None otherwise.
Sourcepub fn as_mut_match_or(&mut self) -> Option<&mut &'a PatternMatchOr>
pub fn as_mut_match_or(&mut self) -> Option<&mut &'a PatternMatchOr>
Returns Some if self is a mutable reference of variant MatchOr, and None otherwise.
Sourcepub fn expect_match_or(self) -> &'a PatternMatchOrwhere
Self: Debug,
pub fn expect_match_or(self) -> &'a PatternMatchOrwhere
Self: Debug,
Sourcepub fn match_or(self) -> Option<&'a PatternMatchOr>
pub fn match_or(self) -> Option<&'a PatternMatchOr>
Returns Some if self is of variant MatchOr, and None otherwise.