pub enum SourceType {
Python(PySourceType),
Toml(TomlSourceType),
Markdown,
}Expand description
The type of a source file.
Variants
Python(PySourceType)
The file contains Python source code.
Toml(TomlSourceType)
The file contains TOML.
Markdown
The file contains Markdown.
Implementations
Sourceimpl SourceType
impl SourceType
Sourcepub fn as_python(&self) -> Option<&PySourceType>
pub fn as_python(&self) -> Option<&PySourceType>
Returns Some if self is a reference of variant Python, and None otherwise.
Sourcepub fn as_mut_python(&mut self) -> Option<&mut PySourceType>
pub fn as_mut_python(&mut self) -> Option<&mut PySourceType>
Returns Some if self is a mutable reference of variant Python, and None otherwise.
Sourcepub fn expect_python(self) -> PySourceTypewhere
Self: Debug,
pub fn expect_python(self) -> PySourceTypewhere
Self: Debug,
Sourcepub fn python(self) -> Option<PySourceType>
pub fn python(self) -> Option<PySourceType>
Returns Some if self is of variant Python, and None otherwise.
Sourcepub fn as_toml(&self) -> Option<&TomlSourceType>
pub fn as_toml(&self) -> Option<&TomlSourceType>
Returns Some if self is a reference of variant Toml, and None otherwise.
Sourcepub fn as_mut_toml(&mut self) -> Option<&mut TomlSourceType>
pub fn as_mut_toml(&mut self) -> Option<&mut TomlSourceType>
Returns Some if self is a mutable reference of variant Toml, and None otherwise.
Sourcepub fn expect_toml(self) -> TomlSourceTypewhere
Self: Debug,
pub fn expect_toml(self) -> TomlSourceTypewhere
Self: Debug,
Sourcepub fn toml(self) -> Option<TomlSourceType>
pub fn toml(self) -> Option<TomlSourceType>
Returns Some if self is of variant Toml, and None otherwise.
Sourcepub const fn is_markdown(&self) -> bool
pub const fn is_markdown(&self) -> bool
Returns true if self is of variant Markdown.