pub enum SideEffect {
Absent,
Possible,
Present,
}Expand description
Whether an expression has no side effects, may have side effects, or is assumed to have side effects.
Variants
Absent
The expression is definitely side-effect-free.
Possible
The expression may have side effects (e.g., f-string interpolation
may invoke __format__ or __str__).
Present
The expression is assumed to have side effects.
Implementations