pub fn is_empty_f_string(expr: &ExprFString) -> boolExpand description
Returns true if the expression definitely resolves to the empty string, when used as an f-string
expression.
pub fn is_empty_f_string(expr: &ExprFString) -> boolReturns true if the expression definitely resolves to the empty string, when used as an f-string
expression.