pub fn map_callable(decorator: &Expr) -> &Expr
Given an Expr that can be callable or not (like a decorator, which could be used with or without explicit call syntax), return the underlying callable.
Expr