Functions
- parenthesized_
range - Returns the
TextRangeof a given expression including parentheses, if the expression is parenthesized; orNone, if the expression is not parenthesized.
TextRange of a given expression including parentheses, if the expression is
parenthesized; or None, if the expression is not parenthesized.