Module str
ruff_
python_
ast
0.1.0
Module str
Module Items
Enums
Functions
In crate ruff_
python_
ast
ruff_python_ast
Module
str
Enums

Quote
Enumeration of the two kinds of quotes that can be used for Python string/f/t-string/bytestring literals
Triple
Quotes
Functions

is_
triple_
quote
Return
true
if the string is a triple-quote string or byte prefix.
leading_
quote
Return the leading quote for a string, template, or bytes literal (e.g.,
"""
).
raw_
contents
Strip the leading and trailing quotes from a string. Assumes that the string is a valid string literal, but does not verify that the string is a “simple” string literal (i.e., that it does not contain any implicit concatenations).
trailing_
quote
Return the trailing quote string for a string, template, or bytes literal (e.g.,
"""
).