Enums
- AnyString
Prefix - Enumeration of all the possible valid prefixes prior to a Python string literal.
- Byte
String Prefix - Enumeration of the valid prefixes a bytestring literal can have.
- FString
Prefix - Enumeration of the valid prefixes an f-string literal can have.
- String
Literal Prefix - Enumerations of the valid prefixes a string literal can have.
- TString
Prefix - Enumeration of the valid prefixes a t-string literal can have.