pub enum StringLiteralPrefix {
Empty,
Unicode,
Raw {
uppercase: bool,
},
}Expand description
Enumerations of the valid prefixes a string literal can have.
Bytestrings and f-strings are excluded from this enumeration, as they are represented by different AST nodes.
Variants
Empty
Just a regular string with no prefixes
Unicode
A string with a u or U prefix, e.g. u"foo".
Note that, despite this variant’s name,
it is in fact a no-op at runtime to use the u or U prefix
in Python. All Python-3 strings are unicode strings;
this prefix is only allowed in Python 3 for backwards compatibility
with Python 2. However, using this prefix in a Python string
is mutually exclusive with an r or R prefix.
Raw
A “raw” string, that has an r or R prefix,
e.g. r"foo\." or R'bar\d'.
Implementations