BytesLiteralValue

Struct BytesLiteralValue 

pub struct BytesLiteralValue { /* private fields */ }
The value representing a ExprBytesLiteral.

Implementations

Source

impl BytesLiteralValue

pub fn single(value: BytesLiteral) -> Self

Create a new bytestring literal with a single BytesLiteral part.

pub fn concatenated(values: Vec<BytesLiteral>) -> Self

Creates a new bytestring literal with the given values that represents an implicitly concatenated bytestring.

Panics

Panics if values has less than 2 elements. Use BytesLiteralValue::single instead.

pub const fn is_implicit_concatenated(&self) -> bool

Returns true if the bytestring is implicitly concatenated.

pub fn as_slice(&self) -> &[BytesLiteral]

Returns a slice of all the BytesLiteral parts contained in this value.

pub fn iter(&self) -> Iter<'_, BytesLiteral>

Returns an iterator over all the BytesLiteral parts contained in this value.

pub fn iter_mut(&mut self) -> IterMut<'_, BytesLiteral>

Returns an iterator over all the BytesLiteral parts contained in this value that allows modification.

pub fn is_empty(&self) -> bool

Return true if the node represents an empty bytestring.

Note that a BytesLiteralValue node will always have >=1 BytesLiteral parts inside it. This method checks whether the value of the concatenated parts is equal to the empty bytestring, not whether the bytestring has 0 parts inside it.

pub fn len(&self) -> usize

Returns the length of the concatenated bytestring.

pub fn bytes(&self) -> impl Iterator<Item = u8> + '_

Returns an iterator over the bytes of the concatenated bytestring.