ExprCompare

Struct ExprCompare 

pub struct ExprCompare {
    pub node_index: AtomicNodeIndex,
    pub range: TextRange,
    pub ops: Box<[CmpOp]>,
    pub operands: Box<[Expr]>,
    pub runtime_comparators: Option<Vec<Option<Expr>>>,
}
A comparison or chain of comparisons.

operands contains all operands in source order, including the leftmost operand. For example, a < b <= c has operands [a, b, c] and operators [Lt, LtE]. There is at least one operator, and operands.len() == ops.len() + 1.

See also Compare.

Fields

node_index: AtomicNodeIndexrange: TextRangeops: Box<[CmpOp]>operands: Box<[Expr]>runtime_comparators: Option<Vec<Option<Expr>>>

Implementations

Source

impl ExprCompare

pub fn first_operand(&self) -> &Expr

Returns the initial operand (a in a < b <= c).

Panics

Panics if there are no operands. The parser always produces at least two operands, synthesizing an invalid name expression for a missing operand during error recovery.

pub fn second_operand(&self) -> &Expr

Returns the right operand of the first comparison (b in a < b <= c).

Panics

Panics if there are fewer than two operands. See Self::first_operand.

pub fn first_operator(&self) -> CmpOp

Returns the first comparison operator (< in a < b <= c).

Panics

Panics if there are no operators. The parser always produces at least one operator.

pub fn comparators(&self) -> &[Expr]

Returns all operands after the initial operand ([b, c] in a < b <= c).

Panics

Panics if there are no operands. See Self::first_operand.

pub fn as_single(&self) -> Option<(&Expr, &CmpOp, &Expr)>

Returns (left, operator, right) if there is exactly one operator and two operands.

pub fn iter( &self, ) -> impl DoubleEndedIterator<Item = (&Expr, &CmpOp, &Expr)> + ExactSizeIterator

Iterates over each comparison as (left, operator, right).

For a < b <= c, yields (a, <, b) followed by (b, <=, c).