pub struct FStringFlags(/* private fields */);Expand description
Flags that can be queried to obtain information regarding the prefixes and quotes used for an f-string.
Note: This is identical to TStringFlags except that
the implementation of the prefix method of the
StringFlags trait returns a variant of
AnyStringPrefix::Format.
Notes on usage
If you’re using a Generator from the ruff_python_codegen crate to generate a lint-rule fix
from an existing f-string literal, consider passing along the FString::flags field. If you
don’t have an existing literal but have a Checker from the ruff_linter crate available,
consider using Checker::default_fstring_flags to create instances of this struct; this method
will properly handle nested f-strings. For usage that doesn’t fit into one of these categories,
the public constructor FStringFlags::empty can be used.
Implementations
Sourceimpl FStringFlags
impl FStringFlags
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Construct a new FStringFlags with no flags set.
See FStringFlags::with_quote_style, FStringFlags::with_triple_quotes, and
FStringFlags::with_prefix for ways of setting the quote style (single or double),
enabling triple quotes, and adding prefixes (such as r), respectively.
See the documentation for FStringFlags for additional caveats on this constructor, and
situations in which alternative ways to construct this struct should be used, especially
when writing lint rules.
pub fn with_quote_style(self, quote_style: Quote) -> Self
pub fn with_triple_quotes(self, triple_quotes: TripleQuotes) -> Self
pub fn with_unclosed(self, unclosed: bool) -> Self
pub fn with_prefix(self, prefix: FStringPrefix) -> Self
pub const fn prefix(self) -> FStringPrefix