StringLiteralFlags

Struct StringLiteralFlags 

pub struct StringLiteralFlags(/* private fields */);
Flags that can be queried to obtain information regarding the prefixes and quotes used for a string literal.

Notes on usage

If you’re using a Generator from the ruff_python_codegen crate to generate a lint-rule fix from an existing string literal, consider passing along the StringLiteral::flags field or the result of the StringLiteralValue::first_literal_flags method. If you don’t have an existing string but have a Checker from the ruff_linter crate available, consider using Checker::default_string_flags to create instances of this struct; this method will properly handle surrounding f-strings. For usage that doesn’t fit into one of these categories, the public constructor StringLiteralFlags::empty can be used.

Implementations

Source

impl StringLiteralFlags

pub fn empty() -> Self

Construct a new StringLiteralFlags with no flags set.

See StringLiteralFlags::with_quote_style, StringLiteralFlags::with_triple_quotes, and StringLiteralFlags::with_prefix for ways of setting the quote style (single or double), enabling triple quotes, and adding prefixes (such as r or u), respectively.

See the documentation for StringLiteralFlags for additional caveats on this constructor, and situations in which alternative ways to construct this struct should be used, especially when writing lint rules.

pub fn with_quote_style(self, quote_style: Quote) -> Self

pub fn with_triple_quotes(self, triple_quotes: TripleQuotes) -> Self

pub fn with_unclosed(self, unclosed: bool) -> Self

pub fn with_prefix(self, prefix: StringLiteralPrefix) -> Self

pub fn with_invalid(self) -> Self

pub const fn prefix(self) -> StringLiteralPrefix