pub struct Token { /* private fields */ }Implementations
Sourceimpl Token
impl Token
pub fn new(kind: TokenKind, range: TextRange, flags: TokenFlags) -> Token
Sourcepub const fn as_tuple(&self) -> (TokenKind, TextRange)
pub const fn as_tuple(&self) -> (TokenKind, TextRange)
Returns the token as a tuple of (kind, range).
Sourcepub fn is_triple_quoted_string(self) -> bool
pub fn is_triple_quoted_string(self) -> bool
Returns true if the current token is a triple-quoted string of any kind.
Panics
If it isn’t a string or any f/t-string tokens.
Sourcepub fn string_quote_style(self) -> Quote
pub fn string_quote_style(self) -> Quote
Sourcepub fn unwrap_string_flags(self) -> AnyStringFlags
pub fn unwrap_string_flags(self) -> AnyStringFlags
Returns the AnyStringFlags style for the current string token of any kind.
Panics
If it isn’t a string or any f/t-string tokens.
Sourcepub fn string_flags(self) -> Option<AnyStringFlags>
pub fn string_flags(self) -> Option<AnyStringFlags>
Returns true if the current token is a string and it is raw.