Functions
- indentation
- Extract the leading indentation from a line.
- trailing_
comment_ start_ offset - If a
Rangedhas a trailing comment, return the index of the hash. - trailing_
lines_ end - Return the end offset at which the empty lines following a statement.